"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const sqlite = __importStar(require("sqlite"));
const SQL = require('sql-template-strings');
const path_1 = require("path");
class SqliteStoreBase {
    constructor(config) {
        this.hasInit = false;
        this.config = config;
        this.prefix = config.prefix || '';
        this.db = null;
    }
    getSid(sid) {
        return this.prefix + sid;
    }
    async init() {
        if (!this.db) {
            this.db = await sqlite.open(this.config.path, { cached: true });
            await this.db.migrate({
                migrationsPath: path_1.join(__dirname, 'migrations')
            });
            this.hasInit = true;
        }
    }
    async get(sid) {
        await this.init();
        const time = new Date().getTime();
        const resp = await this.db.get(SQL `SELECT * FROM sessions WHERE sid = ${this.getSid(sid)} AND ${time} < expires`);
        if (!resp) {
            return null;
        }
        return JSON.parse(resp.data);
    }
    async set(sid, session) {
        await this.init();
        const serialized = JSON.stringify(session);
        const msTtl = new Date().getTime() + this.config.ttl;
        const stmt = await this.db.prepare('INSERT INTO sessions (sid, data, expires) VALUES (:sid, :data, :expires)', {
            ':sid': this.getSid(sid),
            ':data': serialized,
            ':expires': msTtl
        });
        await stmt.run();
    }
    async destroy(sid) {
        await this.init();
        await this.db.run(SQL `DELETE FROM sessions WHERE sid = ${this.getSid(sid)}`);
    }
    async all() {
        await this.init();
        const time = new Date().getTime();
        const data = await this.db.all(`SELECT * FROM sessions WHERE ${time} < expires`);
        return data.map(raw => {
            return JSON.parse(raw.data);
        });
    }
    async length() {
        await this.init();
        const time = new Date().getTime();
        const data = await this.db.get(`SELECT count(*) as total FROM sessions WHERE ${time} < expires`);
        return data.total;
    }
    async clear() {
        await this.init();
        await this.db.run(`DELETE FROM sessions`);
    }
    async touch(sid, session) {
        await this.init();
        await this.destroy(sid);
        await this.set(sid, session);
    }
    /**
     * Have to manually call this to remove stale entries
     */
    async removeExpiredSessions() {
        await this.init();
        const time = new Date().getTime();
        await this.db.run(`DELETE FROM sessions WHERE ${time} > expires`);
    }
}
exports.SqliteStoreBase = SqliteStoreBase;
//# sourceMappingURL=SqliteStoreBase.js.map